@@ -1,14 +1,16 @@
 import sys
 import os
+import pickle
 import pathlib
 import shutil
+import logging
 
 import pylogconf.core
-from pytconf import register_endpoint, register_main, config_arg_parse_and_launch
+from pytconf import register_endpoint, register_main, config_arg_parse_and_launch, get_free_args
 
-from pydmt.configs import ConfigSudo, ConfigFlow, ConfigOutput, ConfigTarget
+from pydmt.configs import ConfigSudo, ConfigFlow, ConfigOutput, ConfigTarget, ConfigLogging
 from pydmt.core.pydmt import PyDMT
-from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
+from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION, LOGGER_NAME
 from pydmt.utils.subprocess import check_call
 
 from pydmt.features.sphinx import FeatureSphinx
@@ -70,6 +72,7 @@ def add_to_path():
         ConfigFlow,
         ConfigOutput,
         ConfigTarget,
+        ConfigLogging,
     ],
 )
 def build():
@@ -78,6 +81,9 @@ def build():
     pylogconf.core.setup()
     p = PyDMT()
 
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     add_all_features(p)
 
     stats = p.build_all()
@@ -90,6 +96,7 @@ def build():
         ConfigSudo,
         ConfigFlow,
         ConfigOutput,
+        ConfigLogging,
     ],
 )
 def build_venv():
@@ -98,6 +105,9 @@ def build_venv():
     pylogconf.core.setup()
     p = PyDMT()
 
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     f = FeatureVenv()
     f.setup(p)
 
@@ -111,6 +121,7 @@ def build_venv():
         ConfigSudo,
         ConfigFlow,
         ConfigOutput,
+        ConfigLogging,
     ],
 )
 def build_reqs():
@@ -119,6 +130,9 @@ def build_reqs():
     pylogconf.core.setup()
     p = PyDMT()
 
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     f = FeatureReqs()
     f.setup(p)
 
@@ -132,6 +146,7 @@ def build_reqs():
         ConfigSudo,
         ConfigFlow,
         ConfigOutput,
+        ConfigLogging,
     ],
 )
 def build_tools():
@@ -140,6 +155,9 @@ def build_tools():
     pylogconf.core.setup()
     p = PyDMT()
 
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     f = FeatureApt()
     f.setup(p)
     f = FeatureNpm()
@@ -150,7 +168,10 @@ def build_tools():
 
 
 @register_endpoint(
-    description="Clean all generated files"
+    description="Clean all generated files",
+    configs=[
+        ConfigLogging,
+    ],
 )
 def clean() -> None:
     add_to_path()
@@ -158,6 +179,9 @@ def clean() -> None:
     pylogconf.core.setup()
     p = PyDMT()
 
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     add_all_features(p)
 
     shutil.rmtree(".pydmt")
@@ -165,13 +189,33 @@ def clean() -> None:
 
 
 @register_endpoint(
-    description="Clean all files and pydmt cache"
+    description="Clean all files and pydmt cache",
+    configs=[
+        ConfigLogging,
+    ],
 )
 def clean_hard() -> None:
+    logger = logging.getLogger(LOGGER_NAME)
+    logger.setLevel(ConfigLogging.loglevel)
+
     shutil.rmtree(".pydmt")
     check_call(["git", "clean", "-qffxd"])
 
 
+@register_endpoint(
+    description="print a pickle file for debug purposes",
+    configs=[
+    ],
+    allow_free_args=True,
+)
+def print_pickle() -> None:
+    for filename in get_free_args():
+        with open(filename, "rb") as file_handle:
+            print(f"{filename}")
+            for x, y in pickle.load(file_handle).items():
+                print(x, y)
+
+
 @register_main(
     app_name=APP_NAME,
     version=VERSION_STR,
